@@ -90,6 +90,12 @@ class PowerBIReport(BaseModel):
     webUrl: Optional[str]
 
 
+class PowerBIPage(BaseModel):
+    name: str
+    displayName: str
+    order: int
+
+
 class PowerBITile(BaseModel):
     id: str
     title: str = ""
@@ -152,6 +158,21 @@ class WorkspaceInfo(BaseModel):
     dashboards: List[WorkspaceInfoDashboard] = []
 
 
+class AuthenticationError(Exception):
+    def __init__(self, body) -> None:
+        super().__init__(
+            f"Authentication error: {body}.\n"
+            f"Please\n"
+            f"  1. Enable Power BI admin read-only API for the app\n"
+            f"  2. Enable service principal to use Power BI APIs for the app\n"
+        )
+
+
+class EntityNotFoundError(Exception):
+    def __init__(self, body) -> None:
+        super().__init__(f"EntityNotFound error: {body}")
+
+
 class PowerBIClient:
     AUTHORITY = "https://login.microsoftonline.com/{tenant_id}"
     SCOPES = ["https://analysis.windows.net/powerbi/api/.default"]
@@ -224,6 +245,21 @@ class PowerBIClient:
             url, List[PowerBIReport], transform_response=lambda r: r.json()["value"]
         )
 
+    def get_pages(self, group_id: str, report_id: str) -> List[PowerBIPage]:
+        # https://docs.microsoft.com/en-us/rest/api/power-bi/reports/get-pages-in-group
+        url = f"{self.API_ENDPOINT}/groups/{group_id}/reports/{report_id}/pages"
+
+        try:
+            return self._call_get(
+                url, List[PowerBIPage], transform_response=lambda r: r.json()["value"]
+            )
+        except EntityNotFoundError as e:
+            logger.error(
+                f"Unable to find report {report_id} in workspace {group_id}\n"
+                f"Please add the service principal as a viewer to the workspace"
+            )
+            raise e
+
     def get_workspace_info(self, workspace_ids: List[str]) -> List[WorkspaceInfo]:
         def create_scan() -> str:
             # https://docs.microsoft.com/en-us/rest/api/power-bi/admin/workspace-info-post-workspace-info
@@ -302,11 +338,14 @@ class PowerBIClient:
         transform_response: Callable[[requests.Response], Any] = lambda r: r.json(),
     ) -> T:
         result = requests.get(url, headers=self._headers)
-        assert (
-            result.status_code != 401
-        ), "Authentication error. Please enable read-only Power BI admin API access for the app."
+        body = result.content.decode()
 
-        assert result.status_code == 200, f"GET {url} failed, {result.content.decode()}"
+        if result.status_code == 401:
+            raise AuthenticationError(body)
+        elif result.status_code == 404:
+            raise EntityNotFoundError(body)
+        elif result.status_code != 200:
+            raise AssertionError(f"GET {url} failed: {result.status_code}\n{body}")
 
         logger.debug(f"Response from {url}:")
         logger.debug(json.dumps(result.json(), indent=2))
@@ -370,7 +409,7 @@ class PowerBIExtractor(BaseExtractor):
         dataset_map = {d.id: d for d in self.client.get_datasets(workspace.id)}
 
         for wds in workspace.datasets:
-            sources = []
+            expressions = []
             tables = []
             for table in wds.tables:
                 tables.append(
@@ -388,13 +427,19 @@ class PowerBIExtractor(BaseExtractor):
                 )
 
                 for source in table.source:
-                    sources.append(source["expression"])
+                    expressions.append(source["expression"])
 
-            source_datasets = [
-                str(dataset)
-                for source in sources
-                for dataset in PowerQueryParser.parse_source_datasets(source)
-            ]
+            source_datasets = []
+            for expression in expressions:
+                try:
+                    source_datasets.extend(
+                        PowerQueryParser.parse_source_datasets(expression)
+                    )
+                except Exception as e:
+                    logger.error(
+                        f"Failed to parse expression: {expression} for dataset {wds.id}"
+                    )
+                    logger.exception(e)
 
             ds = dataset_map.get(wds.id, None)
             if ds is None:
@@ -409,7 +454,7 @@ class PowerBIExtractor(BaseExtractor):
                     tables=tables,
                     name=wds.name,
                     url=ds.webUrl,
-                    source_datasets=unique_list(source_datasets),
+                    source_datasets=unique_list([str(d) for d in source_datasets]),
                     description=wds.description,
                     workspace=PbiWorkspace(id=workspace.id, name=workspace.name),
                 ),
@@ -444,6 +489,16 @@ class PowerBIExtractor(BaseExtractor):
                 PowerBIDashboardType.REPORT, workspace, wi_report.appId, app_map
             )
 
+            # The "app" version of report doesn't have pages
+            charts = None
+            if wi_report.appId is None:
+                # Log errors instead of throwing exceptions as this API call requires extra permissions
+                try:
+                    pages = self.client.get_pages(workspace.id, wi_report.id)
+                    charts = self.transform_pages_to_charts(pages)
+                except Exception as e:
+                    logger.exception(e)
+
             dashboard = Dashboard(
                 logical_id=DashboardLogicalID(
                     dashboard_id=wi_report.id,
@@ -453,6 +508,7 @@ class PowerBIExtractor(BaseExtractor):
                     description=wi_report.description,
                     title=wi_report.name,
                     power_bi=pbi_info,
+                    charts=charts,
                 ),
                 source_info=SourceInfo(
                     main_url=report.webUrl,
@@ -537,3 +593,7 @@ class PowerBIExtractor(BaseExtractor):
             Chart(title=t.title, url=t.embedUrl, chart_type=ChartType.OTHER)
             for t in tiles
         ]
+
+    @staticmethod
+    def transform_pages_to_charts(pages: List[PowerBIPage]) -> List[Chart]:
+        return [Chart(title=p.displayName, chart_type=ChartType.OTHER) for p in pages]
