@@ -3,8 +3,6 @@ import math
 from datetime import datetime
 from typing import Collection, Dict, List, Optional, Tuple
 
-from metaphor.models.crawler_run_metadata import Platform
-from metaphor.models.metadata_change_event import DataPlatform, Dataset
 from pydantic import parse_raw_as
 
 from metaphor.common.event_util import ENTITY_TYPES
@@ -13,6 +11,8 @@ from metaphor.common.filter import DatabaseFilter
 from metaphor.common.logger import get_logger
 from metaphor.common.usage_util import UsageUtil
 from metaphor.common.utils import start_of_day
+from metaphor.models.crawler_run_metadata import Platform
+from metaphor.models.metadata_change_event import DataPlatform, Dataset
 from metaphor.snowflake.accessed_object import AccessedObject
 from metaphor.snowflake.auth import connect
 from metaphor.snowflake.usage.config import SnowflakeUsageRunConfig
@@ -73,7 +73,7 @@ class SnowflakeUsageExtractor(BaseExtractor):
         )
 
         excluded_usernames_clause = (
-            f"and USER_NAME NOT IN ({','.join(['%s'] * len(config.excluded_usernames))})"
+            f"and q.USER_NAME NOT IN ({','.join(['%s'] * len(config.excluded_usernames))})"
             if len(config.excluded_usernames) > 0
             else ""
         )
