@@ -1,6 +1,19 @@
 from itertools import chain
 from typing import Collection, Dict, List, Optional, Tuple
 
+from pydantic import parse_raw_as
+from restapisdk.models.search_object_header_type_enum import SearchObjectHeaderTypeEnum
+from restapisdk.restapisdk_client import RestapisdkClient
+
+from metaphor.common.entity_id import (
+    dataset_fullname,
+    to_dataset_entity_id,
+    to_virtual_view_entity_id,
+)
+from metaphor.common.event_util import ENTITY_TYPES
+from metaphor.common.extractor import BaseExtractor
+from metaphor.common.logger import get_logger
+from metaphor.common.utils import unique_list
 from metaphor.models.crawler_run_metadata import Platform
 from metaphor.models.metadata_change_event import (
     Chart,
@@ -16,19 +29,6 @@ from metaphor.models.metadata_change_event import (
     VirtualViewLogicalID,
     VirtualViewType,
 )
-from pydantic import parse_raw_as
-from restapisdk.models.search_object_header_type_enum import SearchObjectHeaderTypeEnum
-from restapisdk.restapisdk_client import RestapisdkClient
-
-from metaphor.common.entity_id import (
-    dataset_fullname,
-    to_dataset_entity_id,
-    to_virtual_view_entity_id,
-)
-from metaphor.common.event_util import ENTITY_TYPES
-from metaphor.common.extractor import BaseExtractor
-from metaphor.common.logger import get_logger
-from metaphor.common.utils import unique_list
 from metaphor.thought_spot.config import ThoughtspotRunConfig
 from metaphor.thought_spot.models import (
     AnswerMetadata,
@@ -109,6 +109,11 @@ class ThoughtspotExtractor(BaseExtractor):
     def populate_virtual_views(self, tables: Dict[str, SourceMetadata]):
         for table in tables.values():
             table_id = table.header.id
+            tags = [
+                tag.name
+                for tag in table.header.tags
+                if not (tag.isDeleted or tag.isHidden or tag.isDeprecated)
+            ]
             view = VirtualView(
                 logical_id=VirtualViewLogicalID(
                     name=table_id, type=VirtualViewType.THOUGHT_SPOT_DATA_OBJECT
@@ -127,6 +132,7 @@ class ThoughtspotExtractor(BaseExtractor):
                     description=table.header.description,
                     type=mapping_data_object_type(table.type),
                     url=f"{self.base_url}/#/data/tables/{table_id}",
+                    tags=tags,
                 ),
             )
             self._virtual_views[table_id] = view
